어베스트 | 회원가입

로그인 | VPS :16020100 | Japan | English
개인용 | 업무용 | 고객지원 | 제품구매

손님으로 접속하셨습니다. 회원 로그인 회원 가입 |
| # 회원가입
이메일: |
이름: |
전화: |
나이(년도) |
국가: |
시/도: |
| [ 개인정보보호를 위한 이용자 동의사항 ] (자세한 내용은 "개인정보취급방침"을 확인하시기 바랍니다) ◆ 수집하는 개인정보 항목 회사는 견적 신청, 다운로드, 회원가입 등을 위해 아래와 같은 개인정보를 수집하고 있습니다. - 수집항목 : 이름 , 회사명 , 지역 , 전화번호 , 이메일 등 - 개인정보 수집방법 : 홈페이지 ◆ 개인정보의 수집 및 이용목적 회사는 수집한 개인정보를 다음의 목적을 위해 활용합니다.. * 상담 : 제품상담 및 문의 * 결제 : 구매 제품에 대한 대금을 지급 처리 * 전송 : 제품소개서, 유/무료 버전 제품 다운로드 및 라이선스 제공 * 배송 : 구매 제품 우편 배달 * 마케팅활동 : 자사 마케팅 행사 안내(세미나,컨퍼런스,DM,eDM 등) * 고객관리 : 재구매 확인 후 할인혜택 적용 및 라이선스 분실시 재전송 ◆ 개인정보의 보유 및 이용기간 원칙적으로, 개인정보 수집 및 이용목적이 달성된 후에는 해당 정보를 지체 없이 파기합니다. 단, 관계법령의 규정에 의하여 보존할 필요가 있는 경우 회사는 아래와 같이 관계법령에서 정한 일정한 기간 동안 회원정보를 보관합니다. 보존 항목 : 이름 , 회사명 , 지역 , 전화번호 , 이메일 등 보존 근거 : 신용정보의 이용 및 보호에 관한 법률 보존 기간 : 5년 [ 소프트웨어 이용약관 ] 소프트메일에서 어베스트 무료 버전 제품을 사용해 주셔서 감사합니다. 어베스트는 보안 제품으로 사용자의 시스템 환경과 타 어플리케이션(드라이버 포함)과의 충돌로 인하여 오작동의 가능성이 있으며 회사는 오작동에 대하여 책임지지 아니합니다. 구체적인 내용은 어베스트 설치시 사용자 약관을 반드시 읽고 동의하시기 바랍니다. AVAST END USER LICENSE AGREEMENT (FREE VERSION) PLEASE READ THE TERMS AND CONDITIONS OF THIS LICENSE AGREEMENT (“AGREEMENT”) CAREFULLY BEFORE USING THE SOFTWARE (AS DEFINED BELOW). THIS IS A LEGALLY BINDING CONTRACT BETWEEN YOU AND AVAST SOFTWARE a.s., A COMPANY DULY ORGANIZED AND EXISTING UNDER THE LAWS OF THE CZECH REPUBLIC, REGISTERED IN THE COMMERCIAL REGISTER MAINTAINED BY THE MUNICIPAL COURT IN PRAGUE IN SECTION B, INSERT NO. 11402 (“AVAST”). BY ASSENTING ELECTRONICALLY, INSTALLING OR USING THIS SOFTWARE YOU ACCEPT ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT. If you do not agree with the terms and conditions of this Agreement, do not continue the installation process and delete or destroy all copies of the Software in your possession. This Agreement accompanies certain software (including any upgrades or updates thereto as provided by AVAST, the “Software”) and related explanatory written materials (the “Documentation”). 1. License AVAST grants to you a non-exclusive perpetual license to use the Software and the Documentation for so long as AVAST makes the Software available, provided that you agree to the terms and conditions of this Agreement. 2. Permitted Use of the Software You may install and use the Software on an unlimited number of computers. The Software must be used exclusively by you or members of your household solely for private non-commercial purposes. You may also make one backup copy of the Software. ANY USE OF THE SOFTWARE OTHER THAN AS EXPRESSLY AUTHORIZED BY THIS SECTION OR ANY RESALE OR FURTHER DISTRIBUTION OF THE SOFTWARE CONSTITUTES A MATERIAL BREACH OF THIS AGREEMENT AND MAY VIOLATE APPLICABLE COPYRIGHT LAWS. 3. Upgrades and Updates Upgrades and updates of the Software shall be provided to you by AVAST as long as and to the extent in which AVAST in its exclusive discretion makes such upgrades and updates available to the users of the free version of the Software. 4. Ownership Rights The Software and Documentation is the intellectual property of AVAST and is protected by applicable copyright laws, international treaty provisions and other applicable laws of the country in which the Software is being used. The structure, organization and code of the Software are valuable trade secrets and confidential information of AVAST. To the extent you provide any comments or suggestions about the Software to AVAST, AVAST shall have the right to retain and use any such comments or suggestions in our current or future products or services, without further compensation to you and without your approval of such retention or use. Except as stated in this Agreement, your possession, installation and use of the Software does not grant you any rights or title to any intellectual property rights in the Software or Documentation. All rights to the Software and Documentation, including all associated copyrights, patents, trade secret rights, trademarks and other intellectual property rights, are reserved by AVAST. 5. Restrictions You may not copy or use the Software or the Documentation except as set forth in Section 2 of this Agreement. You may not remove any proprietary notices or labels on the Software; any copies that you are permitted to make pursuant to this Agreement must contain the same copyright and other proprietary notices that appear on and in the Software. You agree not to modify, adapt, translate, reverse engineer, decompile or disassemble the Software or otherwise attempt to discover the source code of the Software or algorithms contained therein or create any derivative works from the Software. You are not permitted to use the Software in connection with the provision of any commercial services which include processing or transferring the data of or for other persons or entities (“Data”), including cloud computing and “Software as a Service” solutions, providing storage capacities for Data; transmitting, routing of or providing connection to Data, or providing information search tool services. You may not permit third parties to benefit from the use or functionality of the Software via a timesharing, service bureau or other similar arrangement. 6. Transfer You may not rent, lease, sub-license, or lend the Software or the Documentation or any portions thereof. You may, however, transfer all your rights to use the Software and the Documentation to another person provided that (i) the transferee accepts the terms of this Agreement; (ii) you transfer the Software, including all copies, updates and prior versions, and all Documentation to such person; and (iii) you retain no copies of the Software or of the Documentation, including but not limited to copies stored on your computer. Partial transfer of your rights under this Agreement is strictly prohibited. 7. Disclaimers and Exclusion of Liability Be aware that the Software may make changes to your computer that may adversely affect its functionality, such as deleting system or application files identified (correctly or incorrectly) by the Software as infected. You acknowledge and agree to such changes to your computer that may occur as a result of your use of the Software. The Software is not fault-tolerant and as such is not designed for use in hazardous environments requiring fail-safe performance. AVAST AND ITS DISTRIBUTORS DO NOT AND CANNOT WARRANT THE PERFORMANCE OR RESULTS YOU MAY OBTAIN BY USING THE SOFTWARE OR DOCUMENTATION. THE REMEDY IN THIS SECTION STATES THE SOLE AND EXCLUSIVE REMEDIES FOR AVAST'S OR ITS DISTRIBUTORS’ OR AGENTS’ BREACH OF WARRANTY. THE SOFTWARE IS PROVIDED “AS IS” AND AVAST AND ITS DISTRIBUTORS MAKE NO EXPRESS OR IMPLIED WARRANTIES OR CONDITIONS AND, TO THE MAXIMUM EXTENT PERMITTED BY LAW, DISCLAIM ANY AND ALL CONDITIONS AND WARRANTIES IMPLIED BY STATUTE, COMMON LAW OR JURISPRUDENCE, INCLUDING BUT NOT LIMITED TO IMPLIED WARRANTIES OF NONINFRINGEMENT OF THIRD PARTY RIGHTS, MERCHANTABILITY, SUITABLE QUALITY OR FITNESS FOR ANY PARTICULAR PURPOSE. YOU AGREE AND ACCEPT THAT, TO THE FULL EXTENT PERMITTED BY LAW, IN NO EVENT WILL AVAST OR ITS DISTRIBUTORS OR AGENTS BE LIABLE TO YOU FOR ANY DAMAGES, ESPECIALLY FOR CONSEQUENTIAL, INCIDENTAL OR SPECIAL DAMAGES, INCLUDING ANY LOST PROFITS, LOST SAVINGS OR LOST DATA, EVEN IF AVAST OR ITS DISTRIBUTOR OR AGENT HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES, OR FOR ANY CLAIM BY ANY THIRD PARTY. TO THE FULL EXTENT PERMITTED BY LAW, YOU AGREE AND ACCEPT THAT IN NO CASE SHALL AVAST’S OR ITS DISTRIBUTORS’ OR AGENTS’ LIABILITY FOR ANY DAMAGE EXCEED THE LESSER OF FIVE U.S. DOLLARS ($5.00) OR THE AMOUNT OF THE ONE YEAR LICENSE FEE FOR AVAST’S COMMERCIAL PRODUCT CLOSEST TO YOUR FREE VERSION OF THE SOFTWARE. THE FOREGOING EXCLUSIONS AND LIMITATIONS OF LIABILITY OF AVAST AND ITS DISTRIBUTORS DO NOT LIMIT POTENTIAL LIABILITY FOR DEATH, PERSONAL INJURY OR FRAUD OVER THE EXTENT PERMITTED BY APPLICABLE LAWS. 8. Privacy; Processing of Personal Information The Software automatically and from time to time may collect certain information, which may include personally identifiable information, from the computer on which it is installed, including: 8.1 URLs of visited websites that the Software identifies as potentially infected, together with the information on the nature of identified threats (e.g. viruses, Trojans, tracking cookies and any other forms of malware) and URLs of several sites visited before the infection was identified to ascertain the source of the infection; 8.2 Information and files (including executable files) on your computer identified by the Software as potentially infected, together with the information about the nature of identified threats; 8.3 Information about the sender and subject of emails identified by the Software as potentially infected, together with the information on the nature of identified threats; 8.4 Information contained in emails reported by you as spam or as incorrectly identified as spam by the Software; 8.5 Copies of the files identified by the Software as potentially infected or parts thereof may be automatically sent to AVAST for further examination and analysis; 8.6 Certain information about your computer hardware, software and/or network connection; 8.7 Certain information about the installation and operation of the Software and encountered errors or problems; 8.8 Statistical information about threats detected by the Software; and 8.9 If your version of the Software includes the Website reputation function, which provides information on reputation of web sites as potential sources of malware, and you set the Website reputation function to active, the Software may send AVAST the URLs of all websites you want to visit and the results of your web searches through search engines. The information collected by the Software is generally not correlated with any other personal information related to you that AVAST may be processing such as information given by you to AVAST or its distributors or agents during the process of ordering and downloading the Software. Unless you have permitted otherwise, the information collected by the Software is used anonymously in aggregation with similar information from other users of the Software for analytical purposes to identify new viruses and threats and for improvement and development of the Software and for statistical purposes. By using the Software you acknowledge and agree that AVAST or its distributors or agents may collect and use the information as described above. You are giving this consent on behalf of all users of all computers where the Software will be used under this license and you accept full responsibility for informing all users and acquiring their fully informed, free and valid consent with processing of their personal information by the Software as described above. Notwithstanding anything to the contrary in the AVAST privacy policy, you consent during the term of this Agreement and for one (1) year thereafter to (i) AVAST sharing information collected by you during your installation or registration of the Software with AVAST’s distributors and other business partners and (ii) use of such information by AVAST, its distributors and other business partners to present you with information that may be relevant to you, including offers of software, services or other products. The collected information may be transferred to third parties or to other countries that may have less protective data protection laws than the country or region in which you are situated (including the European Union). AVAST takes measures to ensure that any collected information will receive an adequate level of protection if and when transferred. Notwithstanding anything to the contrary in this Agreement or any Documentation or other materials provided to you in connection with the Software, AVAST reserves all rights to cooperate with any legal process or government inquiry (including, but not limited to, court orders and law enforcement requests) related to your use of the Software. In connection with such cooperation, AVAST may provide documents and information relevant to a court subpoena or government or other legal investigation, which may include disclosure of your personally identifiable information. AVAST may also use statistics derived from the collected information to track and publish reports on security risk trends. By using the Software, you acknowledge and agree that AVAST may collect, transmit, store, disclose and analyze such information for any of the foregoing purposes listed in this Section. 9. U.S. Government Restricted Rights This Software and Documentation are deemed to be “commercial computer software” and “commercial computer software documentation”, respectively, and subject to certain restricted rights as identified in FAR Section 52.227-19 "Commercial Computer Software - Restricted Rights" and DFARS 227.7202, “Rights in Commercial Computer Software or Commercial Computer Software Documentation”, as applicable, or any successor U.S. regulations. Any use, modification, reproduction, release, performance, display or disclosure of the Software by the U.S. Government shall be done solely in accordance with this Agreement. 10. Export Regulations You agree and accept that the Software and the Documentation may be subject to import and export laws of any country, including those of the United States (specifically the Export Administration Regulations (EAR)) and the European Union. If you transfer or export the Software, which in all cases must be done in accordance with this Agreement, you agree to and acknowledge that you are exclusively responsible for complying with all applicable laws and regulations, including but not limited to all United States and European Union trade sanctions and export regulations (including any activities relating to nuclear, chemical or biological materials or weapons, missiles or technology capable of mass destruction), regardless of the country in which you reside in or of which you are a citizen. 11. Governing Law and Jurisdiction The laws of the State of California, excluding its conflicts of law rules, govern this Agreement and your use of the Software and the Documentation. The application of the United Nations Convention on Contracts for the International Sale of Goods is expressly excluded. The courts located within the county of Santa Clara, California shall be the exclusive jurisdiction and venue for any dispute or legal matter arising out of or in connection with this Agreement or your use of the Software and the Documentation. Notwithstanding this, you agree that AVAST shall still be allowed to apply for injunctive remedies (or an equivalent type of urgent legal relief) in any jurisdiction. 12. General This Agreement is the entire agreement between you and AVAST relating to the Software and Documentation. This Agreement supersedes all prior or contemporaneous oral or written communications, proposals, and representations with respect to the Software or Documentation. Notwithstanding the foregoing, nothing in this Agreement will diminish any rights you may have under existing consumer protection legislation or other applicable laws in your jurisdiction that may not be waived by contract. This Agreement will immediately terminate upon your breach of any obligation contained herein (especially your obligations in Sections 2, 5, 10) and you shall cease use and destroy all copies of the Software and Documentation in your possession. AVAST reserves the right to any other remedies available under law in the event your breach of this Agreement adversely affects AVAST or its distributors or agents. The limitations of liability and disclaimers of warranty and damages contained herein shall survive termination of this Agreement. This Agreement may be modified by the Documentation. No provision hereof shall be deemed waived unless such waiver shall be in writing and signed by AVAST. If any provision of this Agreement is held invalid, the remainder of this Agreement shall continue in full force and effect. If you have any questions regarding this Agreement or wish to request any information from AVAST, please write to AVAST Software, Budejovicka 1518/13A, 140 00 Praha 4, Czech Republic, e-mail: support@avast.com, tel.: +420 274 005 777 or visit our support page at www.avast.com/support. (주)소프트메일 어베스트팀 http://www.softmail.co.kr E-mail: info@softmail.co.kr 전화: 02-3486-9220 팩스: 02-3486-9331
위 개인정보 취급방침 및 이용약관에 동의하시겠습니까? 예 아니오

| 뉴스수신해지 | 사용약관 | 개인정보취급방침 | 연락처 | 파트너 | 쇼핑몰 |

| (주)소프트메일, 사업자번호 214-87-14889 | 통신판매업신고번호 구로제0716호 대표이사 오봉근 | ( 08389 ) 서울시 구로구 디지털로 272 한신IT타워 1305호 대표전화 1661-9331 팩스 02-3486-9331 avast! is a registered trademark of AVAST Software a.s. and is used in www.softmail.co.kr (avastkorea.com) under non-exclusive license from AVAST Software a.s.